@@ -144,7 +144,7 @@ def write_coverage_data(app, *args):
     open(f"{tmpdir}/docscov.json", "w").write(textwrap.dedent(f"""
         {{
             "schemaVersion": 1,
-            "label": "{config["badge_title"]}",
+            "label": "{config["badge_label"]}",
             "message": "{round(coverage_percentage)}%",
             "color": "{color}"
         }}
